| Title: | Displays a Dad Joke |
|---|---|
| Description: | Displays a terrible joke, the kind only dads crack. |
| Authors: | Shambhavi Priyam [aut, cre] |
| Maintainer: | Shambhavi Priyam <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0 |
| Built: | 2026-05-11 06:06:42 UTC |
| Source: | https://github.com/cran/dadjoke |
Displays a terrible joke, the kind only dads crack.
dadjoke()dadjoke()
dadjoke()dadjoke()