Welcome to ClientVPS Mirrors

Help for package dadjoke
Title: Displays a Dad Joke
Version: 1.0
Maintainer: Shambhavi Priyam <priyam@coll.mpg.de>
Description: Displays a terrible joke, the kind only dads crack.
Depends: R (≥ 3.0.0)
License: GPL-2
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2020-10-06 00:36:26 UTC; priyam
Author: Shambhavi Priyam [aut, cre]
Repository: CRAN
Date/Publication: 2020-10-13 13:50:06 UTC

Displays a Dad Joke

Description

Displays a terrible joke, the kind only dads crack.

Usage

dadjoke()

Examples


dadjoke()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.